@@ -6,7 +6,7 @@
 #          The projects homepage is dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2011 by Ted Kulp
 #          The projects homepage is: cmsmadesimple.org
-# Version: 0.8
+# Version: 0.9.1
 # File   : AdvancedContent.module.php
 # Purpose: initial module class.
 # License: GPL
@@ -15,12 +15,62 @@
 
 class AdvancedContent extends CMSModule
 {
-	/**
-	 * @access private
-	 * @var array
-	 */
+	#private $_allowedParams = array(
+	#	'cancel'                   => CLEAN_INT,
+	#	'input_id'                 => CLEAN_STRING,
+	#	'input_fields'             => CLEAN_STRING,
+	#	'input_tpl'                => CLEAN_STRING,
+	#	'submit'                   => CLEAN_INT,
+	#	'tpl_name'                 => CLEAN_STRING,
+	#	'template'                 => CLEAN_STRING,
+	#	'active'                   => CLEAN_STRING,
+	#	'block_type'               => CLEAN_STRING,
+	#	'block'                    => CLEAN_STRING,
+	#	'returnid'                 => CLEAN_STRING,
+	#	'default'                  => CLEAN_STRING,
+	#	'smarty'                   => CLEAN_STRING,
+	#	'allow_none'               => CLEAN_STRING,
+	#	'active_tab'               => CLEAN_STRING,
+	#	'errormessage'             => CLEAN_STRING,
+	#	'message'                  => CLEAN_STRING,
+	#	'old_type'                 => CLEAN_STRING,
+	#	'new_type'                 => CLEAN_STRING,
+	#	'submit_bulkaction'        => CLEAN_INT,
+	#	'ajax'                     => CLEAN_INT,
+	#	'tpl_id'                   => CLEAN_STRING,
+	#	'submit_prefs'             => CLEAN_INT,
+	#	'use_advanced_pageoptions' => CLEAN_INT,
+	#	'uninstall_action'         => CLEAN_INT,
+	#	'block_display_settings'   => CLEAN_STRING,
+	#	'collapse_block_default'   => CLEAN_INT,
+	#	'message_display_settings' => CLEAN_STRING,
+	#	'group_display_settings'   => CLEAN_STRING,
+	#	'collapse_group_default'   => CLEAN_INT,
+	#	'use_expire_date'          => CLEAN_INT,
+	#	'AdvancedContentStartDate' => CLEAN_INT,
+	#	'AdvancedContentStartTime' => CLEAN_INT,
+	#	'AdvancedContentEndDate'   => CLEAN_INT,
+	#	'AdvancedContentEndTime'   => CLEAN_INT,
+	#	'feu_access'               => CLEAN_INT,
+	#	'redirect_page'            => CLEAN_INT,
+	#	'feu_params'               => CLEAN_STRING,
+	#	'feu_params_smarty'        => CLEAN_STRING,
+	#	'inherit_feu_params'       => CLEAN_STRING,
+	#	'custom_params'            => CLEAN_STRING,
+	#	'custom_params_smarty'     => CLEAN_STRING,
+	#	'inherit_custom_params'    => CLEAN_STRING,
+	#	'feu_action'               => CLEAN_INT,
+	#	'hide_menu_item'           => CLEAN_INT,
+	#	'item_type'                => CLEAN_STRING,
+	#	'item_display'             => CLEAN_INT,
+	#	'item_id'                  => CLEAN_STRING,
+	#	'content_id'               => CLEAN_INT,
+	#	'template_id'              => CLEAN_INT,
+	#	'set_default'              => CLEAN_INT
+	#);
+	
 	private $_displaySettings = array();
-	private $_feuGroups       = false;
+	
 	protected $_pp = '<div style="float:right"><form action="https://www.paypal.com/cgi-bin/webscr" method="post">
 <input type="hidden" name="cmd" value="_s-xclick" />
 <input type="hidden" name="hosted_button_id" value="FA2D3FPLSTAKJ" />
@@ -28,292 +78,225 @@ class AdvancedContent extends CMSModule
 <img alt="" border="0" src="https://www.paypal.com/de_DE/i/scr/pixel.gif" width="1" height="1" />
 </form></div>';
 
-	var $_inheritables = array( 0 => array(
-			'feu_access'     =>-1,
-			'redirect_page'  =>-1,
-			'redirect_params'=>-1,
-			'evaluate_smarty'=>-1,
-			'feu_action'     =>-1,
-			'start_date'     =>-1,
-			'end_date'       =>-1,
-			'hide_menu_item' =>-1,
-			'use_expire_date'=>-1));
+	public $_inheritables = array( 0 => array(
+			'feu_access'           => -1,
+			'redirect_page'        => -1,
+			'custom_params'        => -1,
+			'custom_params_smarty' => -1,
+			'feu_params'           => -1,
+			'feu_params_smarty'    => -1,
+			'feu_action'           => -1,
+			'start_date'           => -1,
+			'end_date'             => -1,
+			'hide_menu_item'       => -1,
+			'use_expire_date'      => -1));
 	
-	#var $_loadedProps = array();
-	
-	function AdvancedContent()
+	public final function __construct()
 	{
-		parent::CMSModule();
+		parent::__construct();
 		$this->RegisterContentType('Content2', dirname(__FILE__) .
 			DIRECTORY_SEPARATOR . 'contenttype.Content2.php', $this->lang('AdvancedContent'));
-		#global $config;
-		#$this->smarty->plugins_dir[] = $config["root_path"].'/modules/AdvancedContent/plugins';
+		$config = cmsms()->GetConfig();
+		$this->smarty->plugins_dir[] = $config["root_path"].'/modules/AdvancedContent/plugins';
 	}
 	
-	function GetName()
+	public final function GetName()
 	{
 		return 'AdvancedContent';
 	}
 	
-	function GetFriendlyName()
+	public final function GetFriendlyName()
 	{
 		return $this->Lang('AdvancedContent');
 	}
 	
-	function GetVersion()
+	public final function GetVersion()
 	{
-		return '0.8';
+		return '0.9.1';
 	}
 	
-	function GetHelp()
+	public final function GetHelp()
 	{
-		$path = dirname(__FILE__) . DIRECTORY_SEPARATOR . 'doc' . DIRECTORY_SEPARATOR;
-		if(file_exists($path . 'help_' . $this->curlang . '.html'))
+		if(isset($_GET['action']) && $_GET['action'] == 'showmodulehelp')
 		{
-			return $this->_pp . file_get_contents($path . 'help_' . $this->curlang . '.html');
+			$block_help = array();
+			foreach($this->_get_custom_block_types() as $blockType)
+			{
+				$block_help[] = $blockType->GetHelp();
+			}
+			$block_help = implode('<div class="pageheader"></div>', $block_help);
+			
+			$plugin_help = array();
+			$d = dir(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'plugins');
+			while ($entry = $d->read())
+			{
+				if(preg_match('/^function\.(\w+)\.php$/i',$entry,$matches))
+				{
+					if(!function_exists('smarty_cms_function_' . $matches[1]))
+					{
+						require_once(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'plugins' . DIRECTORY_SEPARATOR . $entry);
+					}
+					if(function_exists('smarty_cms_help_function_' . $matches[1]))
+					{
+						$plugin_help[] = call_user_func('smarty_cms_help_function_' . $matches[1]);
+					}
+				}
+			}
+			$plugin_help = implode('<div class="pageheader"></div>', $plugin_help);
+			
+			$help_file = dirname(__FILE__) . DIRECTORY_SEPARATOR . 'doc' . DIRECTORY_SEPARATOR . 'help_' . $this->curlang . '.html';
+			if(!is_file($help_file))
+			{
+				$help_file = dirname(__FILE__) . DIRECTORY_SEPARATOR . 'doc' . DIRECTORY_SEPARATOR . 'help_en_US.html';
+			}
+			
+			$helptext = $this->_pp;
+			
+			if($block_help || $plugin_help)
+			{
+				$helptext .= $this->StartTabHeaders() . $this->SetTabHeader('help', lang('help'), true);
+				if($block_help)
+				{
+					$helptext .= $this->SetTabHeader('custom_blocktypes', $this->lang('custom_blocktypes'), false);
+				}
+				if($plugin_help)
+				{
+					$helptext .= $this->SetTabHeader('plugins', $this->lang('plugins'), false);
+				}
+				$helptext .= $this->EndTabHeaders() . $this->StartTabContent() . $this->StartTab('help');
+			}
+			
+			$helptext .= file_get_contents($help_file);
+			
+			if($block_help || $plugin_help)
+			{
+				$helptext .= $this->EndTab();
+				if($block_help)
+				{
+					$helptext .= $this->StartTab('custom_blocktypes') . $block_help . $this->EndTab();
+				}
+				if($plugin_help)
+				{
+					$helptext .= $this->StartTab('plugins') . $plugin_help . $this->EndTab();
+				}
+				$helptext .= $this->EndTabContent();
+			}
+			return $helptext;
 		}
-		return $this->_pp . file_get_contents($path . 'help_en_US.html');
+		return true;
 	}
 	
-	function GetAuthor()
+	public final function GetAuthor()
 	{
 		return 'Georg Busch (NaN)';
 	}
 	
-	function GetAuthorEmail()
+	/**
+	 * @todo plugin changelog
+	 */
+	public final function GetChangeLog()
 	{
-		return;
+		if(isset($_GET['action']) && $_GET['action'] == 'showmoduleabout')
+		{
+			$blockChangeLog = array();
+			foreach($this->_get_custom_block_types() as $blockType)
+			{
+				$blockChangeLog[] = $blockType->GetChangeLog();
+			}
+			$blockChangeLog = implode('',$blockChangeLog);
+			$changeLog      = $this->_pp;
+			if($blockChangeLog)
+			{
+				$changeLog .=
+					$this->StartTabHeaders() .
+						$this->SetTabHeader('help', lang('help'), true) .
+						$this->SetTabHeader('custom_blocktypes', $this->lang('custom_blocktypes'), false) .
+					$this->EndTabHeaders() .
+					$this->StartTabContent() . 
+						$this->StartTab('help');
+			}
+			$changeLog .= file_get_contents(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'doc' . DIRECTORY_SEPARATOR . 'changelog.html');
+			if($blockChangeLog)
+			{
+				$changeLog .= 
+						$this->EndTab() .
+						$this->StartTab('custom_blocktypes') . 
+							$blockChangeLog . 
+						$this->EndTab() .
+					$this->EndTabContent();
+			}
+			return $changeLog;
+		}
+		return true;
 	}
 	
-	function GetChangeLog()
-	{
-		return $this->_pp . file_get_contents(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'doc' . DIRECTORY_SEPARATOR . 'changelog.html');
-	}
-	
-	function HasContentType()
+	public final function HasContentType()
 	{
 		return true;
 	}
 	
-	function IsPluginModule()
+	public final function IsPluginModule()
 	{
 		return true;
 	}
 	
-	function HasAdmin()
+	public final function HasAdmin()
 	{
 		return true;
 	}
 	
-	function GetAdminSection()
+	public final function GetAdminSection()
 	{
 		return 'extensions';
 	}
 	
-	function GetAdminDescription()
+	public final function GetAdminDescription()
 	{
 		return $this->lang('admindescription');
 	}
 	
-	function VisibleToAdminUser()
+	public final function VisibleToAdminUser()
 	{
 		return $this->CheckPermission('Manage AdvancedContent Preferences') || $this->CheckPermission('Manage AdvancedContent MultiInputs') || $this->CheckPermission('Manage AdvancedContent MultiInput Templates');
 	}
 	
-	function MinimumCMSVersion()
+	public final function MinimumCMSVersion()
 	{
-		return "1.9.4.1";
+		return "1.9";
 	}
 	
-	function MaximumCMSVersion()
+	public final function MaximumCMSVersion()
 	{
-		return "1.99";
+		return "1.11";
 	}
 	
-	function InstallPostMessage()
+	public final function InstallPostMessage()
 	{
 		return $this->Lang('postinstall', $this->GetVersion());
 	}
 	
-	function UninstallPostMessage()
+	public final function UninstallPostMessage()
 	{
 		return $this->Lang('postuninstall', $this->GetVersion());
 	}
 	
-	function UninstallPreMessage()
+	public final function UninstallPreMessage()
 	{
 		return $this->Lang('confirmuninstall',$this->lang('warninguninstall'.$this->GetPreference('uninstall_action')));
 	}
 	
-	function HandlesEvents()
+	public final function HandlesEvents()
 	{
 		return true;
 	}
 	
-	function DoAction($action, $id, $params, $returnid = '')
+	public final function DoAction($action, $id, $params, $returnid = '')
 	{
 		switch($action) {
-			/*
-			case 'displayContentBlock':
-				#ToDo: create the content block form via php or js?
-				#$contentops =& cmsms()->GetContentOperations();
-				#$contentobj = $contentops->LoadContentFromId($params['content_id']);
-				$contentobj = unserialize(base64_decode($params["serialized_content"]));
-				@ob_end_clean();
-				@ob_start();
-				echo $contentobj->display_content_block($params['block_info'],cms_htmlentities($params['block_info']['content'], ENT_NOQUOTES, get_encoding('')),$params['adding']);
-				ob_end_flush();
-				exit;
-			*/
 			case 'importpages':
-				
-				if(isset($params['old_type']) && isset($params['new_type'])
-				&& $params['old_type'] != '' && $params['new_type'] != ''
-				&& $params['new_type'] != $params['old_type']
-				&& ($params['new_type'] == 'content' || $params['new_type'] == 'content2')
-				&& ($params['old_type'] == 'content' || $params['old_type'] == 'content2'))
-				{
-					$db =& $this->GetDb();
-					$query    = "UPDATE ".cms_db_prefix()."content SET type = ? WHERE type = ?";
-					$dbresult = $db->Execute($query, array($params['new_type'],$params['old_type']));
-					if($dbresult)
-					{
-						$message = $this->lang('success_importpages',$this->lang($params['old_type']), $this->lang($params['new_type']));
-						$_params  = array(
-							'new_type' => $params['new_type'],
-							'old_type' => $params['old_type'],
-							'message'  => 'success_importpages');
-					}
-					else
-					{
-						$_params = array(
-							'new_type'     => $params['new_type'],
-							'old_type'     => $params['old_type'],
-							'errormessage' => 'error_importpages');
-						$errormessage = $this->lang('error_importpages',$this->lang($params['old_type']), $this->lang($params['new_type']));
-					}
-				}
-				else
-				{
-					$_params      = array('errormessage' => 'error_insufficientparams');
-					$errormessage = $this->lang('error_insufficientparams', 'new_type, old_type');
-				}
-				
-				if(isset($params['ajax']))
-				{
-					@ob_end_clean();
-					@ob_start();
-					if(isset($errormessage))
-					{
-						echo '<div class="pageerrorcontainer"><ul class="pageerror"><li>'. $errormessage . '</li></ul></div>';
-					}
-					if(isset($message))
-					{
-						echo '<div class="pagemcontainer"><p class="pagemessage">'.$message.'</p></div>';
-					}
-					ob_end_flush();
-					exit;
-				}
-				$_params['submit'] = true;
-				$this->Redirect($id, 'defaultadmin', $returnid, $_params);
-				break;
-			
 			case 'deleteMultiInput':
-				$items        = array();
-				$_params      = array();
-				$message      = '';
-				$errormessage = '';
-				if(isset($params['input_id']))
-				{
-					$items[] = $params['input_id'];
-				}
-				else if(isset($params['submit_bulkaction']))
-				{
-					foreach($params as $param_name => $param_value)
-					{
-						if(startswith($param_name,'multi_input-'))
-						{
-							$items[] = $param_value;
-						}
-					}
-				}
-				if($this->DeleteMultiInput($items))
-				{
-					$_params['message'] = 'multi_input_deleted';
-					$message .= $this->lang('multi_input_deleted') . "<br />";
-				}
-				else
-				{
-					$_params['errormessage'] = 'error_delete_multi_input';
-					$errormessage .= $this->lang('error_delete_multi_input') . "<br />";
-				}
-				if(!$this->DeleteTplAssoc('multi_input',$items))
-				{
-					$_params['message'] = 'error_delete_multi_input_tpl_assocs';
-					$errormessage .= $this->lang('error_delete_multi_input_tpl_assocs'). "<br />";
-				}
-				$_params['active_tab'] = 'multi_input';
-				
-				if(isset($params['ajax']))
-				{
-					@ob_end_clean();
-					@ob_start();
-					if($errormessage)
-					{
-						echo '<div class="pageerrorcontainer"><ul class="pageerror"><li>'. $errormessage . '</li></ul></div>';
-					}
-					if($message)
-					{
-						echo '<div class="pagemcontainer"><p class="pagemessage">'.$message.'</p></div>';
-					}
-					ob_end_flush();
-					exit;
-				}
-				
-				$this->Redirect($id, 'defaultadmin', $returnid, $_params);
-				break;
-			
 			case 'deleteMultiInputTpl':
-				$_params = array();
-				$message      = '';
-				$errormessage = '';
-				if(isset($params['tpl_id']))
-				{
-					$this->DeleteTemplate($params['tpl_id']);
-					$_params['message'] = 'multi_input_tpl_deleted';
-					$message .= $this->lang('multi_input_tpl_deleted') . "<br />";
-				}
-				else if(isset($params['submit_bulkaction']))
-				{
-					foreach($params as $param_name => $param_value)
-					{
-						if(startswith($param_name,'multi_input_tpl-'))
-						{
-							$this->DeleteTemplate($param_value);
-							$_params['message'] = 'multi_input_tpl_deleted';
-							$message .= $this->lang('multi_input_tpl_deleted') . "<br />";
-						}
-					}
-				}
-				$_params['active_tab'] = 'multi_input_tpl';
-				if(isset($params['ajax']))
-				{
-					@ob_end_clean();
-					@ob_start();
-					if($errormessage)
-					{
-						echo '<div class="pageerrorcontainer"><ul class="pageerror"><li>'. $errormessage . '</li></ul></div>';
-					}
-					if($message)
-					{
-						echo '<div class="pagemcontainer"><p class="pagemessage">'.$message.'</p></div>';
-					}
-					ob_end_flush();
-					exit;
-				}
-				$this->Redirect($id, 'defaultadmin', $returnid, $_params);
-				break;
-				
+			case 'switchParams':
 			case 'default':
 			case 'savePrefs':
 			case 'defaultadmin':
@@ -323,294 +306,82 @@ class AdvancedContent extends CMSModule
 			case 'editMultiInputTpl':
 				parent::DoAction($action, $id, $params, $returnid);
 				break;
-			/*
-			case 'getParams':
-				$module_params = array();
-				$files  = array();
-				$dir    = dirname(__FILE__) . DIRECTORY_SEPARATOR;
-				$d      = dir($dir);
-				while ($entry = $d->read())
-				{
-					if ($entry[0] == '.' || is_dir($dir.$entry) || !is_readable($dir.$entry))
-					{
-						continue;
-					}
-					$content = file_get_contents($dir.$entry);
-					$pattern = '/\$params\[[\'"](\w+)[\'"]\]/i';
-					$matches = array();
-					$result = preg_match_all($pattern, $content, $matches);
-					if ($result && count($matches[1]) > 0)
-					{
-						foreach($matches[1] as $one_param)
-						{
-							$module_params[$one_param] = $one_param;
-						}
-					}
-					$pattern = '/\$blockInfo\[[\'"](\w+)[\'"]\]/i';
-					$matches = array();
-					$result = preg_match_all($pattern, $content, $matches);
-					if ($result && count($matches[1]) > 0)
-					{
-						foreach($matches[1] as $one_param)
-						{
-							$module_params[$one_param] = $one_param;
-						}
-					}
-				}
-				$d->close();
-				
-				echo "<pre>";
-				echo "<code>";
-				print_r($module_params);
-				echo "</code>";
-				echo "</pre>";
-			*/
 			default: break;
 		}
 	}
 	
-	function DoEvent($originator, $eventname, &$params)
+	public final function InitializeFrontend()
 	{
-		if($eventname == 'ContentEditPost' && basename($_SERVER['PHP_SELF']) == 'copycontent.php' && isset($params['content']) && is_object($params['content']) && $params['content']->Type() == 'content2')
-		{
-			if(isset($_GET['content_id']))
-			{
-				$old_content_id = $_GET['content_id'];
-			}
-			else
-			{
-				$old_content_id = $params['content']->Id();
-			}
-			foreach($params['content']->get_content_blocks() as $blockInfo)
-			{
-				$this->SetItemDisplay('block', $blockInfo['id'], $params['content']->Id(), $params['content']->TemplateId(),
-					$this->GetItemDisplay('block', $blockInfo['id'], $old_content_id, $params['content']->TemplateId(), !$blockInfo['collapse']));
-			}
-			foreach($params['content']->get_block_groups() as $groupInfo)
-			{
-				$this->SetItemDisplay('group', $groupInfo['group_id'], $params['content']->Id(), $params['content']->TemplateId(),
-					$this->GetItemDisplay('group', $groupInfo['group_id'], $old_content_id, $params['content']->TemplateId(), !$this->GetPreference('collapse_group_default',1)));
-			}
-		}
-		else if ($eventname == 'ContentPostRender')
-		{
-			$config = cmsms()->GetConfig();
-			$redirect = false;
-			$db =& $this->GetDb();
-			# get all content of type advanced that need to be set to active/inactive
-			$query = "SELECT C.content_id, C.active
-				FROM " . cms_db_prefix() . "content C
-				LEFT JOIN " . cms_db_prefix() . "content_props USE_EXP
-					ON USE_EXP.content_id = C.content_id
-				LEFT JOIN " . cms_db_prefix() . "content_props START_DATE
-					ON START_DATE.content_id = C.content_id
-				LEFT JOIN " . cms_db_prefix() . "content_props END_DATE
-					ON END_DATE.content_id = C.content_id
-				WHERE
-					C.type = ? AND
-					USE_EXP.prop_name = ? AND
-					USE_EXP.content = ? AND (
-						(
-							START_DATE.prop_name = ? AND
-							START_DATE.content <= ? AND
-							END_DATE.prop_name = ? AND
-							END_DATE.content > ? AND
-							C.active = ?
-						)
-						OR
-						(
-							END_DATE.prop_name = ? AND
-							END_DATE.content <= ? AND
-							C.active = ?
-						)
-					)
-				";
-				
-			$dbresult = $db->Execute($query, array('content2', 'use_expire_date',
-				'1', 'start_date', time(), 'end_date', time(), 0, 'end_date',
-				time(), 1));
-			
-			$contents = array();
-			while($dbresult && $row = $dbresult->FetchRow())
-			{
-				if($row['active'])
-				{
-					$contents[$row['content_id']] = 0;
-				}
-				else
-				{
-					$contents[$row['content_id']] = 1;
-				}
-			}
-			if(count($contents))
-			{
-				cmsms()->GetSmarty()->clear_all_cache();
-				foreach($contents as $contentId=>$active)
-				{
-					$query = "UPDATE ". cms_db_prefix() . "content
-						SET active = ? WHERE content_id = ?";
-					$dbresult = $db->Execute($query, array($active, $contentId));
-					if($contentId == cms_utils::get_current_pageid())
-					{
-						$redirect = $contentId;
-					}
-				}
-			}
-			if($redirect)
-			{
-				$this->RedirectContent($redirect);
-			}
-		}
+		$this->SetParameters();
 	}
 	
-	function SetParameters()
+	public final function InitializeAdmin()
+	{
+		#$this->SetParameters();
+	}
+	
+	public final function SetParameters()
 	{
 		$this->RegisterModulePlugin();
 		#$this->RestrictUnknownParams();
-		foreach($this->GetAllowedParameters() as $k => $v) {
-			$this->SetParameterType($k,$v);
-		}
+		#foreach($this->GetAllowedParams() as $k => $v) {
+		#	$this->SetParameterType($k,$v);
+		#}
 	}
 	
-	function GetHeaderHTML()
+	public final function GetHeaderHTML()
 	{
-		global $config;
+		$config = cmsms()->GetConfig();
 		$this->smarty->assign('module_id', 'm1_');
 		$this->smarty->assign('debug',$config['debug'] ? 'true' : '\'\'');
+		
+		$dir = cms_join_path($config['root_path'], 'lib', 'jquery', 'css', 'smoothness');
+		if(!is_dir($dir))
+		{
+			$jq_ui_css = $config['root_url'] . '/modules/' . $this->GetName() . '/css/jquery-ui/base/jquery.ui.all.css';
+		}
+		else 
+		{
+			$d = @dir($dir);
+			while ($entry = $d->read())
+			{
+				if(preg_match('/jquery-ui-[\d\.]+\.custom\.css/i', $entry))
+				{
+					$jq_ui_css = $config['root_url'] . '/lib/jquery/css/smoothness/' . $entry;
+					break;
+				}
+			}
+		}
+		$this->smarty->assign('jq_ui_css', $jq_ui_css);
+		
 		return $this->ProcessTemplate('header.tpl');
 	}
 	
+	public final function LazyLoadFrontend()
+	{
+		return FALSE;
+	}
+	
+	public final function LazyLoadAdmin()
+	{
+	  return TRUE;
+	}
+	
 /**
  * -----------------------------------------------------------------------------
  * Not part of the CMSms module API
  * -----------------------------------------------------------------------------
  */
 	
-	protected function GetAllowedParameters() {
-		return array(
-			'cancel' => CLEAN_INT,
-			'input_id' => CLEAN_STRING,
-			'input_fields' => CLEAN_STRING,
-			'input_tpl' => CLEAN_STRING,
-			'submit' => CLEAN_INT,
-			'tpl_name' => CLEAN_STRING,
-			'template' => CLEAN_STRING,
-			'active' => CLEAN_STRING,
-			'block' => CLEAN_STRING,
-			'default' => CLEAN_STRING,
-			'smarty' => CLEAN_STRING,
-			'allow_none' => CLEAN_STRING,
-			'returnid' => CLEAN_STRING,
-			'active_tab' => CLEAN_STRING,
-			'errormessage' => CLEAN_STRING,
-			'message' => CLEAN_STRING,
-			'old_type' => CLEAN_STRING,
-			'new_type' => CLEAN_STRING,
-			'tpl_id' => CLEAN_STRING,
-			'submit_prefs' => CLEAN_INT,
-			'use_advanced_pageoptions' => CLEAN_INT,
-			'uninstall_action' => CLEAN_INT,
-			'block_display_settings' => CLEAN_STRING,
-			'collapse_block_default' => CLEAN_INT,
-			'message_display_settings' => CLEAN_STRING,
-			'group_display_settings' => CLEAN_STRING,
-			'collapse_group_default' => CLEAN_INT,
-			'use_expire_date' => CLEAN_INT,
-			'start_date_1' => CLEAN_INT,
-			'start_date_2' => CLEAN_INT,
-			'end_date_1' => CLEAN_INT,
-			'end_date_2' => CLEAN_INT,
-			'feu_access' => CLEAN_INT,
-			'redirect_page' => CLEAN_INT,
-			'inherit_redirect_params' => CLEAN_INT,
-			'redirect_params' => CLEAN_STRING,
-			'evaluate_smarty' => CLEAN_INT,
-			'feu_action' => CLEAN_INT,
-			'hide_menu_item' => CLEAN_INT,
-			'item_type' => CLEAN_STRING,
-			'item_display' => CLEAN_INT,
-			'item_id' => CLEAN_STRING,
-			'content_id' => CLEAN_INT,
-			'template_id' => CLEAN_INT,
-			'set_default' => CLEAN_INT,
-			'ajax' => CLEAN_INT,
-			'serialized_content' => CLEAN_STRING,
-			'adding' => CLEAN_INT,
-			'submit_bulkaction' => CLEAN_INT,
-			'content_type' => CLEAN_STRING,
-			'parent_id' => CLEAN_INT,
-			'cachable' => CLEAN_INT,
-			'searchable' => CLEAN_INT,
-			'start_date' => CLEAN_INT,
-			'metadata' => CLEAN_STRING,
-			'end_date' => CLEAN_INT,
-			'AdvancedContentStartTime' => CLEAN_INT,
-			'AdvancedContentStartDate' => CLEAN_INT,
-			'AdvancedContentEndTime' => CLEAN_INT,
-			'AdvancedContentEndDate' => CLEAN_INT,
-			'collapse' => CLEAN_STRING,
-			'editor_groups' => CLEAN_STRING,
-			'editor_users' => CLEAN_STRING,
-			'block_type' => CLEAN_STRING,
-			'type' => CLEAN_STRING,
-			'translate_labels' => CLEAN_STRING,
-			'translate_values' => CLEAN_STRING,
-			'label' => CLEAN_STRING,
-			'required' => CLEAN_STRING,
-			'style' => CLEAN_STRING,
-			'size' => CLEAN_INT,
-			'page_tab' => CLEAN_STRING,
-			'block_tab' => CLEAN_STRING,
-			'block_group' => CLEAN_STRING,
-			'description' => CLEAN_STRING,
-			'no_collapse' => CLEAN_STRING,
-			'maxlength' => CLEAN_INT,
-			'usewysiwyg' => CLEAN_STRING,
-			'oneline' => CLEAN_STRING,
-			'show24h' => CLEAN_INT,
-			'mode' => CLEAN_STRING,
-			'start_hour' => CLEAN_INT,
-			'end_hour' => CLEAN_INT,
-			'start_minute' => CLEAN_INT,
-			'end_minute' => CLEAN_INT,
-			'start_second' => CLEAN_INT,
-			'end_second' => CLEAN_INT,
-			'step_hours' => CLEAN_INT,
-			'step_minutes' => CLEAN_INT,
-			'step_seconds' => CLEAN_INT,
-			'show_clock' => CLEAN_STRING,
-			'sortable' => CLEAN_STRING,
-			'delimiter' => CLEAN_STRING,
-			'items' => CLEAN_STRING,
-			'values' => CLEAN_STRING,
-			'module' => CLEAN_STRING,
-			'params' => CLEAN_NONE,
-			'prefix' => CLEAN_STRING,
-			'exclude' => CLEAN_STRING,
-			'dir' => CLEAN_STRING,
-			'value_delimiter' => CLEAN_STRING,
-			'input_delimiter' => CLEAN_STRING,
-			'allowed_block_types' => CLEAN_STRING,
-			'allowed_multi_inputs' => CLEAN_STRING,
-			'allowed_modules' => CLEAN_STRING,
-			'allowed_block_params' => CLEAN_STRING,
-			'allowed_module_params' => CLEAN_STRING,
-			'date_format' => CLEAN_STRING,
-			'inputname' => CLEAN_STRING,
-			'from' => CLEAN_INT,
-			'to' => CLEAN_INT,
-			'step' => CLEAN_INT,
-			'round' => CLEAN_INT,
-			'heterogeneity' => CLEAN_STRING,
-			'dimension' => CLEAN_STRING,
-			'limits' => CLEAN_STRING,
-			'scale' => CLEAN_STRING,
-			'skin' => CLEAN_STRING,
-			'calculate' => CLEAN_STRING,
-			'onstatechange' => CLEAN_STRING,
-			'callback' => CLEAN_STRING);
-	}
-	
+	#public final function SetAllowedParam($name, $type = 'CLEAN_NONE')
+	#{
+	#	#$this->SetParameterType($name,$type);
+	#	$this->_allowedParams[$name] = $type;
+	#}
+	#
+	#public final function GetAllowedParams() {
+	#	return $this->_allowedParams;
+	#}
 	
 	/**
 	 * function IsVarEmpty($var, $trim, $unsetEmptyIndexes)
@@ -622,7 +393,7 @@ class AdvancedContent extends CMSModule
 	 * @param boolean $unsetEmptyIndexes - true to delete empty elements from array
 	 * @return boolean - true if empty, false if not
 	 */
-	function IsVarEmpty(&$var, $trim = true, $unsetEmptyIndexes = false)
+	public final function IsVarEmpty(&$var, $trim = true, $unsetEmptyIndexes = false)
 	{
 		if (is_array($var))
 		{
@@ -661,7 +432,7 @@ class AdvancedContent extends CMSModule
 	 * @param array $array - the array to clean up
 	 * @return array - an array without empty elements or an empty array
 	 */
-	function CleanArray($array)
+	public final function CleanArray($array)
 	{
 		if (is_array($array))
 		{
@@ -696,7 +467,7 @@ class AdvancedContent extends CMSModule
 	 *
 	 * @return array - a set of pages
 	 */
-	function GetPages()
+	public final function GetPages()
 	{
 		$db =& $this->GetDb();
 		$query = "SELECT C.active, C.type, C.content_id, C.parent_id, C.hierarchy, C.menu_text, CP.content FROM " . cms_db_prefix() . "content C
@@ -717,10 +488,10 @@ class AdvancedContent extends CMSModule
 	 *
 	 * @return string - HTML select element with options
 	 */
-	function CreateRedirectDropdown($id = '', $name = 'redirect_page', $selectedPage = '', $currentPage = '')
+	public final function CreateRedirectDropdown($id = '', $name = 'redirect_page', $selectedPage = '', $currentPage = '', $add_txt = '')
 	{
 		$pages      = $this->GetPages();
-		$dropdown   = '<select name="'.$id.$name.'" onchange="if(!this.value){jQuery(\'.AdvancedContent_redirect_params input\').attr(\'disabled\',\'disabled\');if(jQuery(\'.AdvancedContent_redirect_params\').css(\'display\') != \'none\'){jQuery(\'.AdvancedContent_redirect_params\').slideUp();}}else{jQuery(\'.AdvancedContent_redirect_params input\').removeAttr(\'disabled\');if(jQuery(\'.AdvancedContent_redirect_params\').css(\'display\') == \'none\'){jQuery(\'.AdvancedContent_redirect_params\').slideDown();}}" '.(!$this->GetPreference('use_advanced_pageoptions',1) ? 'disabled="disabled"' : '') .'>';
+		$dropdown   = '<select name="'.$id.$name.'" '.($add_txt != '' ? $add_txt: '').(!$this->GetPreference('use_advanced_pageoptions',0) ? ' disabled="disabled"' : '') .'>';
 		$dropdown  .= '<option value=""' . ($selectedPage == ''?' selected="selected"':'') . '>' . $this->lang('hide_content') . '</option>';
 		$dropdown  .= '<option value="-1"' . ($selectedPage == -1?' selected="selected"':'') . '>' . $this->lang('inherit_from_parent') . '</option>';
 		if(count($pages))
@@ -762,7 +533,7 @@ class AdvancedContent extends CMSModule
 	 * @param mixed $value - the value to check
 	 * @return bool
 	 */
-	function IsTrue($value)
+	public final function IsTrue($value)
 	{
 		return (strtolower($value) === 'true' || $value === 1 || $value === '1' || $value === true);
 	}
@@ -777,7 +548,7 @@ class AdvancedContent extends CMSModule
 	 * @param mixed $value - the value to check
 	 * @return bool
 	 */
-	function IsFalse($value)
+	public final function IsFalse($value)
 	{
 		return (strtolower($value) === 'false' || $value === '0' || $value === 0 || $value === false || $value === '');
 	}
@@ -792,7 +563,7 @@ class AdvancedContent extends CMSModule
 	 * @param int $display - 0 to hide, 1 to show
 	 *
 	 */
-	function SetItemDisplay($item_type, $item_id, $content_id, $template_id, $display)
+	public final function SetItemDisplay($item_type, $item_id, $content_id, $template_id, $display)
 	{
 		$db =& $this->GetDb();
 		$query = "SELECT item_display FROM ". cms_db_prefix() . "module_AdvancedContent_".$item_type."display
@@ -864,7 +635,7 @@ class AdvancedContent extends CMSModule
 	 *
 	 * @return boolean - 0 = hidden, 1 = shown
 	 */
-	function GetItemDisplay($item_type, $item_id, $content_id, $template_id, $default_value = 1)
+	public final function GetItemDisplay($item_type, $item_id, $content_id, $template_id, $default_value = 1)
 	{
 		$ids = array();
 		
@@ -965,7 +736,7 @@ class AdvancedContent extends CMSModule
 		}
 	}
 	
-	function GetMultiInputFull($inputs = array())
+	public final function GetMultiInputFull($inputs = array())
 	{
 		if(!is_array($inputs))
 		{
@@ -996,7 +767,7 @@ class AdvancedContent extends CMSModule
 		return $return_array;
 	}
 	
-	function GetMultiInput($input_id)
+	public final function GetMultiInput($input_id)
 	{
 		$db       =& $this->GetDb();
 		$query    = "SELECT input_fields FROM ". cms_db_prefix() . "module_AdvancedContent_multi_inputs WHERE input_id = ? LIMIT 1";
@@ -1007,7 +778,7 @@ class AdvancedContent extends CMSModule
 		}
 	}
 	
-	function GetMultiInputList()
+	public final function GetMultiInputList()
 	{
 		$db       =& $this->GetDb();
 		$query    = "SELECT A.input_id, B.tpl_name FROM ". cms_db_prefix() . "module_AdvancedContent_multi_inputs A
@@ -1022,7 +793,7 @@ class AdvancedContent extends CMSModule
 		return $return_array;
 	}
 	
-	function AddMultiInput($input_id, $input_fields)
+	public final function AddMultiInput($input_id, $input_fields)
 	{
 		$db    =& $this->GetDb();
 		$query = "SELECT input_id FROM ". cms_db_prefix() . "module_AdvancedContent_multi_inputs
@@ -1040,7 +811,7 @@ class AdvancedContent extends CMSModule
 		return $dbresult;
 	}
 	
-	function UpdateMultiInput($input_id, $input_fields)
+	public final function UpdateMultiInput($input_id, $input_fields)
 	{
 		$db    =& $this->GetDb();
 		$query = "UPDATE ". cms_db_prefix() . "module_AdvancedContent_multi_inputs
@@ -1049,7 +820,7 @@ class AdvancedContent extends CMSModule
 		return $dbresult;
 	}
 	
-	function UpdateTplAssoc($tpl_type, $input_id, $tpl_name)
+	public final function UpdateTplAssoc($tpl_type, $input_id, $tpl_name)
 	{
 		$db    =& $this->GetDb();
 		$query = "UPDATE ". cms_db_prefix() . "module_AdvancedContent_".$tpl_type."_tpl_assocs
@@ -1058,7 +829,7 @@ class AdvancedContent extends CMSModule
 		return $dbresult;
 	}
 	
-	function AddTplAssoc($tpl_type, $input_id, $tpl_name)
+	public final function AddTplAssoc($tpl_type, $input_id, $tpl_name)
 	{
 		$db    =& $this->GetDb();
 		$query = "INSERT INTO ". cms_db_prefix() ."module_AdvancedContent_".$tpl_type."_tpl_assocs
@@ -1067,7 +838,7 @@ class AdvancedContent extends CMSModule
 		return $dbresult;
 	}
 	
-	function DeleteTplAssoc($tpl_type,$input_ids = array())
+	public final function DeleteTplAssoc($tpl_type,$input_ids = array())
 	{
 		$db =& $this->GetDb();
 		if(!is_array($input_ids))
@@ -1089,7 +860,7 @@ class AdvancedContent extends CMSModule
 		return $dbresult;
 	}
 	
-	function DeleteMultiInput($input_ids = array())
+	public final function DeleteMultiInput($input_ids = array())
 	{
 		$db =& $this->GetDb();
 		if(!is_array($input_ids))
@@ -1112,7 +883,7 @@ class AdvancedContent extends CMSModule
 		return $dbresult;
 	}
 	
-	function GetTemplates($prefix)
+	public final function GetTemplates($prefix)
 	{
 		$db     =& $this->GetDb();
 		$query  = "SELECT TPL.template_name, TPL_ASSOCS.* FROM ". cms_db_prefix() . "module_templates TPL
@@ -1143,7 +914,7 @@ class AdvancedContent extends CMSModule
 		return $return_array;
 	}
 	
-	function GetTplList($prefix)
+	public final function GetTplList($prefix)
 	{
 		$prefix = trim($prefix,'_') . '_';
 		$db     =& $this->GetDb();
@@ -1159,7 +930,7 @@ class AdvancedContent extends CMSModule
 		return $return_array;
 	}
 	
-	function IsTplUsed($tpl_name, $assoc_type)
+	public final function IsTplUsed($tpl_name, $assoc_type)
 	{
 		$db     =& $this->GetDb();
 		$query  = "SELECT tpl_name FROM ". cms_db_prefix() . "module_AdvancedContent_".$assoc_type."_tpl_assocs
@@ -1172,35 +943,16 @@ class AdvancedContent extends CMSModule
 		return true;
 	}
 	
-	function &Inheritables($content_id = '')
+	public final function &Inheritables($content_id = '')
 	{
 		$content_id = intval($content_id);
 		if(!isset($this->_inheritables[$content_id]))
 		{
-			$this->_inheritables[$content_id] = array(
-				'feu_access'     =>-1,
-				'redirect_page'  =>-1,
-				'redirect_params'=>-1,
-				'evaluate_smarty'=>-1,
-				'feu_action'     =>-1,
-				'start_date'     =>-1,
-				'end_date'       =>-1,
-				'hide_menu_item' =>-1,
-				'use_expire_date'=>-1);
+			$this->_inheritables[$content_id] = $this->_inheritables[0];
 		}
 		return $this->_inheritables[$content_id];
 	}
 	
-	#function &LoadedProps($content_id = '')
-	#{
-	#	$content_id = intval($content_id);
-	#	if(!isset($this->_loadedProps[$content_id]))
-	#	{
-	#		$this->_loadedProps[$content_id] = array();
-	#	}
-	#	return $this->_loadedProps[$content_id];
-	#}
-	
 	/**
 	 * Inherits a property of a parent page (recursivley)
 	 *
@@ -1211,7 +963,7 @@ class AdvancedContent extends CMSModule
 	 *
 	 * @return array|string - The prop of the last found parent that has no inheritance or an array of items of all parents that have inheritance
 	 */
-	function InheritParentProp($currentId, $parentId, $propName, $currentProp = array())
+	public final function InheritParentProp($currentId, $parentId, $propName, $currentProp = array())
 	{
 		$currentId = intval($currentId);
 		$this->Inheritables($currentId);
@@ -1288,7 +1040,7 @@ class AdvancedContent extends CMSModule
 	 * @return mixed - False if not exists or array('parent_id','prop_value')
 	 *
 	 */
-	function LoadContentProps($contentIds = array(), $props = array(), $attribs = array(), $contentTypes = array(), $limit = '')
+	public final function LoadContentProps($contentIds = array(), $props = array(), $attribs = array(), $contentTypes = array(), $limit = '')
 	{
 		$db  =& cmsms()->GetDb();
 		$ret =  false;
@@ -1390,5 +1142,63 @@ class AdvancedContent extends CMSModule
 		return $ret;
 	}
 	
+	private function &_get_custom_block_types()
+	{
+		$config     = cmsms()->GetConfig();
+		$dir        = cms_join_path($config['root_path'], 'module_custom', 'AdvancedContent', 'lib');
+		$blockTypes = array();
+		
+		if(is_dir($dir))
+		{
+			$contentops =& cmsms()->GetContentOperations();
+			$contentobj = $contentops->CreateNewContent('Content2');
+			$classnames = array();
+			
+			$d = @dir($dir);
+			while($entry = $d->read())
+			{
+				if(preg_match('/class\.(acBlockType_\w+)\.php/', $entry, $matches))
+				{
+					$blockTypes[] = new $matches[1]($contentobj, $params);
+				}
+			}
+		}
+		return $blockTypes;
+	}
+	
+	private function &_get_core_block_types()
+	{
+		$config     = cmsms()->GetConfig();
+		$dir        = dirname(__FILE__) . DIRECTORY_SEPARATOR . 'lib';
+		$blockTypes = array();
+		
+		$contentops =& cmsms()->GetContentOperations();
+		$contentobj = $contentops->CreateNewContent('Content2');
+		$classnames = array();
+		
+		$d = @dir($dir);
+		while($entry = $d->read())
+		{
+			if(preg_match('/class\.(acBlockType_\w+)\.php/', $entry, $matches))
+			{
+				$blockTypes[] = new $matches[1]($contentobj, $params);
+			}
+		}
+		return $blockTypes;
+	}
 }
+
+function AdvancedContent_Autoloader($classname)
+{
+	$config = cmsms()->GetConfig();
+	$fn     = cms_join_path($config['root_path'], 'module_custom', 'AdvancedContent', 'lib', 'class.'.$classname.'.php');
+	if( file_exists($fn) )
+	{
+		require_once($fn);
+		return TRUE;
+	}
+	return FALSE;
+}
+spl_autoload_register('AdvancedContent_Autoloader');
+
 ?>
