@@ -6,7 +6,7 @@
 #          The projects homepage is dev.cmsmadesimple.org/projects/content2/
 #          CMS Made Simple is (c) 2004-2011 by Ted Kulp
 #          The projects homepage is: cmsmadesimple.org
-# Version: 0.8
+# Version: 0.9.1
 # File   : action.defaultadmin.php
 # Purpose: performs the default backend action if "Extensions->AdvancedContent"
 #          is selected
@@ -45,6 +45,62 @@ if($this->CheckPermission('Manage AdvancedContent Preferences'))
 		$this->lang('prefs'),
 		($active_tab=='prefs'?true:''));
 	
+	if($this->GetPreference('switch_redirect_params',false))
+	{
+		$this->smarty->assign('switch_redirect_params_text',$this->lang('switch_redirect_params'));
+		$this->smarty->assign('switch_params1_input',
+		$this->CreateLink($id, 'switchParams', $returnid,
+			cmsms()->get_variable('admintheme')->DisplayImage('icons/system/import.gif', '','','','systemicon') .
+			'&nbsp;' . $this->lang('switch_params', $this->lang('redirectparams'),$this->lang('feu_params')),
+			array('old_type'=>'redirect_params','new_type'=>'feu_params'),
+			'',
+			false,
+			false,
+			'class="AdvancedContent_AJAX" onclick="if(confirm(\''.
+				$this->lang('confirm_switchparams', $this->lang('redirectparams'),$this->lang('feu_params')) .
+				'\')) {AdvancedContent.switchParams(this.href);} return false;"'));
+		
+		$this->smarty->assign('switch_params2_input',
+		$this->CreateLink($id, 'switchParams', $returnid,
+			cmsms()->get_variable('admintheme')->DisplayImage('icons/system/import.gif', '','','','systemicon') .
+			'&nbsp;' . $this->lang('switch_params', $this->lang('redirectparams'),$this->lang('custom_params')),
+			array('old_type'=>'redirect_params','new_type'=>'custom_params'),
+			'',
+			false,
+			false,
+			'class="AdvancedContent_AJAX" onclick="if(confirm(\''.
+				$this->lang('confirm_switchparams', $this->lang('redirectparams'),$this->lang('custom_params')) .
+				'\')) {AdvancedContent.switchParams(this.href);} return false;"'));
+	}
+	#else
+	#{
+	#	$this->smarty->assign('switch_params1_input',
+	#	$this->CreateLink($id, 'switchParams', $returnid,
+	#		cmsms()->get_variable('admintheme')->DisplayImage('icons/system/import.gif', '','','','systemicon') .
+	#		'&nbsp;' . $this->lang('switch_params', $this->lang('custom_params'),$this->lang('feu_params')),
+	#		array('old_type'=>'custom_params','new_type'=>'feu_params'),
+	#		'',
+	#		false,
+	#		false,
+	#		'class="AdvancedContent_AJAX" onclick="if(confirm(\''.
+	#			$this->lang('confirm_switchparams',$this->lang('custom_params'),$this->lang('feu_params')) .
+	#			'\')) {AdvancedContent.switchParams(this.href);} return false;"'));
+	#	
+	#	$this->smarty->assign('switch_params2_input',
+	#	$this->CreateLink($id, 'switchParams', $returnid,
+	#		cmsms()->get_variable('admintheme')->DisplayImage('icons/system/import.gif', '','','','systemicon') .
+	#		'&nbsp;' . $this->lang('switch_params', $this->lang('feu_params'),$this->lang('custom_params')),
+	#		array('old_type'=>'feu_params','new_type'=>'custom_params'),
+	#		'',
+	#		false,
+	#		false,
+	#		'class="AdvancedContent_AJAX" onclick="if(confirm(\''.
+	#			$this->lang('confirm_switchparams',$this->lang('feu_params'),$this->lang('custom_params')) .
+	#			'\')) {AdvancedContent.switchParams(this.href);} return false;"'));
+	#	
+	#}
+	
+	
 	$this->smarty->assign('startform', $this->CreateFormStart($id,
 		'savePrefs', $returnid,'post','multipart/form-data'));
 	$this->smarty->assign('endform', $this->CreateFormEnd());
@@ -126,9 +182,9 @@ if($this->CheckPermission('Manage AdvancedContent Preferences'))
 	$this->smarty->assign('use_advanced_pageoptions_input',
 		$this->CreateInputHidden($id,'use_advanced_pageoptions',0) .
 		$this->CreateInputCheckbox($id, 'use_advanced_pageoptions', 1,
-			$this->GetPreference('use_advanced_pageoptions',1),'onchange="if(!this.checked){jQuery(\'#advanced_default_options input\').attr(\'disabled\',\'disabled\');if(jQuery(\'#advanced_default_options\').css(\'display\') != \'none\'){jQuery(\'#advanced_default_options\').slideUp();}}else{jQuery(\'#advanced_default_options input\').removeAttr(\'disabled\');if(jQuery(\'#advanced_default_options\').css(\'display\') == \'none\'){jQuery(\'#advanced_default_options\').slideDown();}}"'));
+			$this->GetPreference('use_advanced_pageoptions',0),'onchange="if(!this.checked){jQuery(\'#advanced_default_options input\').attr(\'disabled\',\'disabled\');if(jQuery(\'#advanced_default_options\').css(\'display\') != \'none\'){jQuery(\'#advanced_default_options\').slideUp();}}else{jQuery(\'#advanced_default_options input\').removeAttr(\'disabled\');if(jQuery(\'#advanced_default_options\').css(\'display\') == \'none\'){jQuery(\'#advanced_default_options\').slideDown();}}"'));
 	
-	$this->smarty->assign('advanced_default_options_style', !$this->GetPreference('use_advanced_pageoptions',1) ? 'style="display:none"' : '');
+	$this->smarty->assign('advanced_default_options_style', !$this->GetPreference('use_advanced_pageoptions',0) ? 'style="display:none"' : '');
 	# default advanced pageoptions
 	
 	$this->smarty->assign('contentsettings_text', $this->lang('contentsettings'));
@@ -154,14 +210,14 @@ if($this->CheckPermission('Manage AdvancedContent Preferences'))
 	$end_date   = explode(' ', $this->GetPreference("end_date", '1 week'));
 	$this->smarty->assign('start_date_text', $this->lang('startdate'));
 	$this->smarty->assign('start_date_input',
-		$this->CreateInputText($id, 'start_date_1', $start_date[0], 3, 5) .
-		$this->CreateInputDropdown($id, 'start_date_2', $times,'', $start_date[1]) . 
+		$this->CreateInputText($id, 'AdvancedContentStartDate', $start_date[0], 3, 5) .
+		$this->CreateInputDropdown($id, 'AdvancedContentStartTime', $times,'', $start_date[1]) . 
 		'&nbsp;' . $this->lang('aftercurrdate'));
 	
 	$this->smarty->assign('end_date_text', $this->lang('enddate'));
 	$this->smarty->assign('end_date_input',
-		$this->CreateInputText($id, 'end_date_1', $end_date[0], 3, 5) . 
-		$this->CreateInputDropdown($id, 'end_date_2', $times, '', $end_date[1]) . 
+		$this->CreateInputText($id, 'AdvancedContentEndDate', $end_date[0], 3, 5) . 
+		$this->CreateInputDropdown($id, 'AdvancedContentEndTime', $times, '', $end_date[1]) . 
 		'&nbsp;' . $this->lang('afterstartdate'));
 	
 	if( $feusers =& $this->GetModuleInstance('FrontEndUsers' ))
@@ -176,30 +232,50 @@ if($this->CheckPermission('Manage AdvancedContent Preferences'))
 		$this->smarty->assign('feuaccess_input',
 			$this->CreateInputHidden($id,'feu_access','').
 			$this->CreateInputSelectList($id,'feu_access[]',$feuAccess,
-				$selectedGroups, count($feuAccess),!$this->GetPreference('use_advanced_pageoptions',1) ? 'disabled="disabled"' : '',1));
+				$selectedGroups, count($feuAccess),!$this->GetPreference('use_advanced_pageoptions',0) ? 'disabled="disabled"' : '',1));
 		
 		$this->smarty->assign('redirectpage_text', $this->lang('redirectpage'));
 		$this->smarty->assign('redirectpage_input',
 			$this->CreateRedirectDropdown($id,'redirect_page',
 				$this->GetPreference('redirect_page')));
 		
-		$inheritParams = $this->GetPreference('inherit_redirect_params',0);
-		$this->smarty->assign('inherit_redirectparams_text', $this->lang('inherit_from_parent'));
-		$this->smarty->assign('inherit_redirectparams_input',
-			$this->CreateInputHidden($id,'inherit_redirect_params',0) .
-			$this->CreateInputCheckbox($id, 'inherit_redirect_params', 1,
-				$inheritParams, !$this->GetPreference('use_advanced_pageoptions',1) ? 'disabled="disabled"' : ''));
-		
+		$this->smarty->assign('inherit_text', $this->lang('inherit_from_parent'));
 		$this->smarty->assign('redirectparams_text', $this->lang('redirectparams'));
-		$this->smarty->assign('redirectparams_input',
-			$this->CreateInputText($id, 'redirect_params', 
-				$this->GetPreference('redirect_params'), 32, 128,!$this->GetPreference('use_advanced_pageoptions',1) ? 'disabled="disabled"' : ''));
-		
 		$this->smarty->assign('evaluatesmarty_text', $this->lang('evaluatesmarty'));
-		$this->smarty->assign('evaluatesmarty_input',
-			$this->CreateInputHidden($id,'evaluate_smarty',0) .
-			$this->CreateInputCheckbox($id, 'evaluate_smarty', 1,
-				$this->GetPreference('evaluate_smarty'),!$this->GetPreference('use_advanced_pageoptions',1) ? 'disabled="disabled"' : ''));
+		
+		$inheritParams = $this->GetPreference('inherit_feu_params',0);
+		$this->smarty->assign('inherit_feu_params_input',
+			$this->CreateInputHidden($id,'inherit_feu_params',0) .
+			$this->CreateInputCheckbox($id, 'inherit_feu_params', 1,
+				$inheritParams, !$this->GetPreference('use_advanced_pageoptions',0) ? 'disabled="disabled"' : ''));
+		
+		$this->smarty->assign('feu_params_text', $this->lang('feu_params'));
+		$this->smarty->assign('feu_params_input',
+			$this->CreateInputText($id, 'feu_params', 
+				$this->GetPreference('feu_params'), 32, 128,!$this->GetPreference('use_advanced_pageoptions',0) ? 'disabled="disabled"' : ''));
+		
+		$this->smarty->assign('feu_params_smarty_text', $this->lang('feu_params_smarty'));
+		$this->smarty->assign('feu_params_smarty_input',
+			$this->CreateInputHidden($id,'feu_params_smarty',0) .
+			$this->CreateInputCheckbox($id, 'feu_params_smarty', 1,
+				$this->GetPreference('feu_params_smarty'),!$this->GetPreference('use_advanced_pageoptions',0) ? 'disabled="disabled"' : ''));
+		
+		$inheritParams = $this->GetPreference('inherit_custom_params',0);
+		$this->smarty->assign('inherit_custom_params_input',
+			$this->CreateInputHidden($id,'inherit_custom_params',0) .
+			$this->CreateInputCheckbox($id, 'inherit_custom_params', 1,
+				$inheritParams, !$this->GetPreference('use_advanced_pageoptions',0) ? 'disabled="disabled"' : ''));
+		
+		$this->smarty->assign('custom_params_text', $this->lang('custom_params'));
+		$this->smarty->assign('custom_params_input',
+			$this->CreateInputText($id, 'custom_params', 
+				$this->GetPreference('custom_params'), 32, 128,!$this->GetPreference('use_advanced_pageoptions',0) ? 'disabled="disabled"' : ''));
+		
+		$this->smarty->assign('custom_params_smarty_text', $this->lang('custom_params_smarty'));
+		$this->smarty->assign('custom_params_smarty_input',
+			$this->CreateInputHidden($id,'custom_params_smarty',0) .
+			$this->CreateInputCheckbox($id, 'custom_params_smarty', 1,
+				$this->GetPreference('custom_params_smarty'),!$this->GetPreference('use_advanced_pageoptions',0) ? 'disabled="disabled"' : ''));
 		
 		$this->smarty->assign('feuaction_text', $this->lang('showloginform'));
 		$this->smarty->assign('feuaction_input',
@@ -207,7 +283,7 @@ if($this->CheckPermission('Manage AdvancedContent Preferences'))
 				array($this->lang('yes')=>1,
 					$this->lang('no')=>0,
 					$this->lang('inherit_from_parent')=>-1),
-				0,$this->GetPreference('feu_action',1),!$this->GetPreference('use_advanced_pageoptions',1) ? 'disabled="disabled"' : ''));
+				0,$this->GetPreference('feu_action',1),!$this->GetPreference('use_advanced_pageoptions',0) ? 'disabled="disabled"' : ''));
 		
 		$this->smarty->assign('hide_menu_item_text',
 			$this->lang('hide_menu_item'));
@@ -217,7 +293,7 @@ if($this->CheckPermission('Manage AdvancedContent Preferences'))
 					$this->lang('loggedout')=>1,
 					$this->lang('loggedin')=>2,
 					$this->lang('inherit_from_parent')=>-1),
-				0,$this->GetPreference('hide_menu_item',0),!$this->GetPreference('use_advanced_pageoptions',1) ? 'disabled="disabled"' : ''));
+				0,$this->GetPreference('hide_menu_item',0),!$this->GetPreference('use_advanced_pageoptions',0) ? 'disabled="disabled"' : ''));
 	}
 	#---
 	$this->smarty->assign('submit_prefs', $this->CreateInputSubmit($id, 'submit_prefs',
@@ -339,6 +415,9 @@ $this->smarty->assign('end_tabcontent',$this->EndTabContent());
 $this->smarty->assign('end_tab',$this->EndTab());
 $this->smarty->assign('moduleId', $id);
 
+$this->smarty->assign('locale', substr(get_preference(get_userid(),'default_cms_language'), 0, 2));
+
+
 if(isset($params['message']))
 {
 	$this->smarty->assign('message', $this->lang($params['message'], (isset($params['old_type']) && isset($params['new_type']) ? $this->lang($params['old_type']) . ',' . $this->lang($params['new_type']) : '')));
